==> gspiceui-v0.8.90.tar.gz: gspiceui-v0.8.90/src/base/NbkSimrBase.cpp <==
//*****************************************************************************
//                                NbkSimrBase.cpp                             *
//                               -----------------                            *
//  Started     : 05/05/2004                                                  *
//  Last Update : 15/12/2005                                                  *
//  Copyright   : (C) 2004 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#include "base/NbkSimrBase.hpp"

//*****************************************************************************
// Implement an event table in which the events are routed to their respective
// handler functions in the class. If -1 is given as the ID, the given handler
// will be invoked for any event of the specified type.

BEGIN_EVENT_TABLE( NbkSimrBase, wxNotebook )

//  EVT_NOTEBOOK_PAGE_CHANGED(  ID_NBK_GNUCAP, NbkSimrBase::OnNoteBook ) ???
//  EVT_NOTEBOOK_PAGE_CHANGING( ID_NBK_GNUCAP, NbkSimrBase::OnNoteBook ) ???

END_EVENT_TABLE( )

//*****************************************************************************
// Constructor.
//
// Arguments:
//   poParent - The parent window
//   oWinID   - The display object ID
//   roPosn   - The notebook position
//   roSize   - The notebook size

NbkSimrBase::NbkSimrBase( wxWindow * poParent, wxWindowID oWinID )
                        : wxNotebook( poParent, oWinID,
                                      wxDefaultPosition, wxSize( 700, 500 ) )
{
  m_eSimrType = Simulation::eSIMR_NONE;
}

//*****************************************************************************
// Default constructor.
// (Used for two stage creation ie. must call Create( ) method.

NbkSimrBase::NbkSimrBase( void ) : wxNotebook( )
{
  m_eSimrType = Simulation::eSIMR_NONE;
}

//*****************************************************************************
// Destructor.

NbkSimrBase::~NbkSimrBase( )
{
}

//*****************************************************************************
// Set the simulator engine type managed by this notebook.
//
// Argument List:
//   eType - The simulator engine type specifier
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  NbkSimrBase::bSetSimrType( Simulation::eSimrType eType )
{
  if( eType<Simulation::eSIMR_FST || eType>Simulation::eSIMR_LST )
    return( FALSE );

  m_eSimrType = eType;

  return( TRUE );
}

//*****************************************************************************
// Get any error message active in the simulation configuration page.
//
// Return Values:
//   The error message (an empty string if no error active)

const wxString & NbkSimrBase::rosGetErrMsg( void )
{
  PnlAnaBase * poPnlAna=NULL;

  poPnlAna = (PnlAnaBase *) GetPage( GetSelection( ) ); 

  return( poPnlAna->rosGetErrMsg( ) );
}

//*****************************************************************************
// 31/03/2004 ???

void  NbkSimrBase::OnSelChange( wxNotebookEvent & roEvent )
{
  wxEventType  oEvtType = roEvent.GetEventType( ); // ???

  if( oEvtType == wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED )
  {
  }
  else if( oEvtType == wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING )
  {
  }

  roEvent.Skip( );
}

//*****************************************************************************

==> gspiceui-v0.9.33.tar.gz: gspiceui-v0.9.33/src/base/NbkSimrBase.cpp <==
//*****************************************************************************
//                                NbkSimrBase.cpp                             *
//                               -----------------                            *
//  Started     : 05/05/2004                                                  *
//  Last Update : 22/05/2007                                                  *
//  Copyright   : (C) 2004 by MSWaters                                        *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#include "base/NbkSimrBase.hpp"

//*****************************************************************************
// Constructor.
//
// Arguments:
//   poParent - The parent window
//   oWinID   - The display object ID
//   roPosn   - The notebook position
//   roSize   - The notebook size

NbkSimrBase::NbkSimrBase( wxWindow * poParent, wxWindowID oWinID )
                        : wxNotebook( poParent, oWinID )
{
  m_eSimrType = Simulation::eSIMR_NONE;
}

//*****************************************************************************
// Default constructor.
// (Used for two stage creation ie. must call Create( ) method.

NbkSimrBase::NbkSimrBase( void ) : wxNotebook( )
{
  m_eSimrType = Simulation::eSIMR_NONE;
}

//*****************************************************************************
// Destructor.

NbkSimrBase::~NbkSimrBase( )
{
}

//*****************************************************************************
// Set the simulator engine type managed by this notebook.
//
// Argument List:
//   eType - The simulator engine type specifier
//
// Return Values:
//   TRUE  - Success
//   FALSE - Failure

bool  NbkSimrBase::bSetSimrType( Simulation::eSimrType eType )
{
  if( eType<Simulation::eSIMR_FST || eType>Simulation::eSIMR_LST )
    return( FALSE );

  m_eSimrType = eType;

  return( TRUE );
}

//*****************************************************************************
// Get any error message active in the simulation configuration page.
//
// Return Values:
//   The error message (an empty string if no error active)

const wxString & NbkSimrBase::rosGetErrMsg( void )
{
  PnlAnaBase * poPnlAna=NULL;

  poPnlAna = (PnlAnaBase *) GetPage( GetSelection( ) ); 

  return( poPnlAna->rosGetErrMsg( ) );
}

//*****************************************************************************
